.. indicngram documentation master file, created by
   sphinx-quickstart on Sat Sep 14 13:33:27 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

``indicngram``
==============
An n-gram generator for indic languages

What is Ngram?
----------------

An n-gram model is a type of probabilistic model for predicting the
next item in a sequence.  n-grams are used in various areas of
statistical natural language processing and genetic sequence analysis.

An n-gram is a subsequence of n items from a given sequence.  The
items in question can be phonemes, syllables, letters, words or base
pairs according to the application. 

An n-gram of size 1 is referred to as a "unigram"; size 2 is a
"bigram" (or, less commonly, a "digram"); size 3 is a "trigram"; and
size 4 or more is simply called an "n-gram".

.. automodule:: indicngram.core
   :members:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

